/*!
 * AUTHOR: Jon Bourne / jonbourne.com / @jondbourne
 * COMPANY: Digital Pi - Marketing Automation, Consulting and Training
 * WEBSITE: digitalpi.com
 * REVISED: 2018-11-14
 */
;(function(){'use strict';

    var version = '18.11.14';

    var _ = function(msg) {
        if(location.hash === '#debug'){
            console.log(msg);
        }
    };

    // deleteCookie from plainjs.com
    var getCookie = function(name) {
        var v = document.cookie.match('(^|;) ?' + name + '=([^;]*)(;|$)');
        return v ? v[2] : null;
    };

    // setCookie from plainjs.com, modified
    var setCookie = function(name, value, days, domain) {
        var d = new Date();
        d.setTime(d.getTime() + 24*60*60*1000*days);
        var mktoLpDomain = '';
        if(typeof domain === 'string' && domain.length > 0) {
            mktoLpDomain = ';domain=.'+domain;
        }
        document.cookie = name + "=" + value + ";path=/;expires=" + d.toGMTString() + mktoLpDomain;
    };

    // deleteCookie from plainjs.com
    var deleteCookie = function(name) {
        setCookie(name, '', -1);
    };

    var getMunFromPurl = function() {
        if(location.host.indexOf('marketodesigner.com')>0) return false;
        var customLpDomain = (location.host.indexOf('marketo.com') > 0) ? false : true;
        var pathPart = (customLpDomain) ? 2 : 4;
        return location.pathname.split('/')[pathPart] || false;
    };

    var showProcessingMsg = function() {
        var overlay = document.createElement('div');
        overlay.id = 'knitpurl';
        overlay.setAttribute('style', 'position:fixed;width:100%;height:100%;top:0;left:0;right:0;bottom:0;background-color:rgba(255,255,255,0.9);z-index:99999;');
        var text = document.createElement('div');
        text.setAttribute('style', 'position:absolute;top:50%;left:50%;font-size:300%;font-family:inherit,sans-serif;color:gray;-ms-transform:translate(-50%,-50%);transform:translate(-50%,-50%);');
        text.innerText = 'Processing...';
        overlay.appendChild(text);
        document.getElementsByTagName('body')[0].appendChild(overlay);
    };

    var reload = function() {
        setTimeout(function(){
            location.reload();
        }, 2000);
    };

    var init = function() {

        if( getMunFromPurl() && typeof window._mkto_person === 'object') {
            _('PURL detected; Marketo Unique Name (MUN) from PURL: ' + getMunFromPurl() );
            _('MUN from cookied Person record detected: ' + _mkto_person.mun );
            _('ID of cookied Person record: ' + _mkto_person.id);

            var p = window._mkto_person;

            if( p.mun !== getMunFromPurl() ) {
                _('Cookie MUN and PURL MUN do not match');

                if( p.email === '' ) {
                    _('Cookied Person record email is empty; assume Person is anonymous');
                    _('Creating _mkto_purl cookie...');
                    setCookie('_mkto_purl',1,1);
                    
                    _('Creating processing message...');
                    showProcessingMsg();

                    _('Reloading page...');
                    reload();
                }
                else {
                    _('Cookied Person record email is not empty; assume cookied Person is known');
                    _('Deleting _mkto_trk cookie to reset cookie to PURL Person record');
                    deleteCookie('_mkto_trk');

                    _('Creating _mkto_purl cookie...');
                    setCookie('_mkto_purl',1,1);
                    
                    _('Creating processing message...');
                    showProcessingMsg();

                    _('Reloading page...');
                    reload();
                }

                if( getCookie('_mkto_purl') > 0 ) {
                    _('_mkto_purl cookie set; Marketo merging anonymous and PURL records; do nothing');
                }
            }
            else {
                _('Cookie MUN and PURL MUN match; do nothing');
            }

        }
        else {
            if( location.host.indexOf('marketodesigner.com')>0 ) {
                console.log('In Marketo landing page editor; do nothing');
            }
            if( !getMunFromPurl() ) {
                _('No PURL detected; do nothing');
            }
            else if( typeof window._mkto_person !== 'object' ) {
                _('_mkto_person object does not exist; do nothing');
            }
        }

    };

    var p = {
        1:"WFhYWCAgIFhYWFhYWFhYICAgIFhYWFg=",2:"ICAgIFhYWA==",
        3:"WFhYWCAgICAgICBYWFhYICAgIFhYWFg=",4:"ICAgIFhYWFhY",
        5:"WFhYWFhYWFhYWFhYWFhYWFhYWFhYWFg=",6:"ICAgIFg=",
        7:"WFhYWCAgIFhYICAgWFhYICAgIFhYWFg="
    };
    var lap = [5,5,3,7,7,3,1,1,5,5,4,2,6];
    var la = '';
    lap.forEach(function(e){
        la+=atob(p[e])+"\n";
    });
    _(la + "Digital Pi - Knit One PURL One\nInfo: digitalpi.com\nVersion: "+version);

    if(location.hash !== '#debug'){
        console.log('To enter debug mode, append #debug to URL');
    }

    if(/complete|interactive|loaded/.test(document.readyState)) { init(); }
    else { document.addEventListener('DOMContentLoaded', init ); }

})();